get-secret
----------

[![Build Status](https://travis-ci.org/TunedMystic/get-secret.svg?branch=master)](https://travis-ci.org/TunedMystic/get-secret)

Simple tool to fetch secrets for your application.
